@@ -6,29 +6,36 @@ import ee
 import pydeck as pdk
 import requests
 
-EARTHENGINE_LAYER_BUNDLE_URL = 'https://cdn.jsdelivr.net/gh/UnfoldedInc/earthengine-layers@master/modules/earthengine-layers/dist/bundle.js'
+EARTHENGINE_LAYER_BUNDLE_URL = 'https://cdn.jsdelivr.net/gh/UnfoldedInc/earthengine-layers@master/modules/earthengine-layers/dist/pydeck_layer_module.min.js'
 
 
 class EarthEngineLayer(pdk.Layer):
     """Wrapper class for using the Earth Engine custom layer with Pydeck
     """
-    def __init__(self, ee_object, credentials=None, **kwargs):
+    def __init__(
+            self,
+            ee_object,
+            vis_params=None,
+            credentials=None,
+            library_url=EARTHENGINE_LAYER_BUNDLE_URL,
+            **kwargs):
         """EarthEngineLayer constructor
 
         Args:
             - ee_object: Earth Engine object
             - vis_params: Dict of vis_params to pass to the Earth Engine backend
-            - credentials: Custom credentials. Saved credentials will be loaded
-              if not passed.
-
+            - credentials: Google OAuth2 credentials object. Saved credentials
+              will be loaded if not passed.
+            - library_url: URL from which to load EarthEngineLayer JavaScript
+              bundle
         """
         super(EarthEngineLayer, self).__init__(
-            'EarthEngineLayer', None, **kwargs)
+            'EarthEngineLayer', None, vis_params=vis_params, **kwargs)
 
         # Should we assume ee has already been initialized?
         ee.Initialize()
 
-        self._set_custom_library()
+        self._set_custom_library(url=library_url)
 
         self.credentials = credentials or ee.data.get_persistent_credentials()
 
@@ -82,10 +89,12 @@ class EarthEngineLayer(pdk.Layer):
 
         token_dict = r.json()
 
-        # Set expiration time
+        # Set expiration time: expires_in * .9
+        # See reference EE API code here:
+        # https://github.com/google/earthengine-api/blob/5909d9a19a9b829d49b69f38ac4205b4924b21c9/javascript/src/apiclient.js#L1107
         self.access_token = token_dict['access_token']
         self.token_expiration = datetime.now() + timedelta(
-            seconds=token_dict['expires_in'] - 1)
+            seconds=token_dict['expires_in'] * .9)
 
     @property
     def token(self):
